@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-persistent
 version: 1.4.0.4
-id: yesod-persistent-1.4.0.4-a374b45e8b618c21d99c5a049b52b954
-key: yesod_CvtMXv7beWE5VUzjiaZTRu
+id: yesod-persistent-1.4.0.4-46b19a60c1c766dabb361044b5599141
+key: yesod_IrWb0ad2klrCzX8H0HLAMd
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,17 +20,17 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-persistent-1.4.0.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-persistent-1.4.0.4
-hs-libraries: HSyesod-persistent-1.4.0.4-CvtMXv7beWE5VUzjiaZTRu
+hs-libraries: HSyesod-persistent-1.4.0.4-IrWb0ad2klrCzX8H0HLAMd
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
-    persistent-template-2.1.6-696af2309e8b2b7d269b843dd09030c3
+    persistent-2.2.4.1-515160ea71a89b76b70a56c63b058aa3
+    persistent-template-2.1.6-42489148129b2fa03f15ca76243f3923
     resource-pool-0.2.3.2-1d704fbdc1706c3584f9663671e9b735
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    yesod-core-1.4.20-a64b314810952b5a1be9638e42c84862
+    yesod-core-1.4.20-0795e5dd1fccda51b978355252f3f0a8
 haddock-interfaces: /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock
 haddock-html: /usr/share/doc/haskell-yesod-persistent/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
